# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import meta_pb2 as voltha__protos_dot_meta__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/events.proto',
  package='voltha',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaZ.github.com/opencord/voltha-protos/v3/go/voltha',
  serialized_pb=b'\n\x1avoltha_protos/events.proto\x12\x06voltha\x1a\x18voltha_protos/meta.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\";\n\x0f\x43onfigEventType\"(\n\x05Types\x12\x07\n\x03\x61\x64\x64\x10\x00\x12\n\n\x06remove\x10\x01\x12\n\n\x06update\x10\x02\"V\n\x0b\x43onfigEvent\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.voltha.ConfigEventType.Types\x12\x0c\n\x04hash\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"*\n\x0cKpiEventType\"\x1a\n\x05Types\x12\t\n\x05slice\x10\x00\x12\x06\n\x02ts\x10\x01\"\xe0\x01\n\x0eMetricMetaData\x12\r\n\x05title\x18\x01 \x01(\t\x12\n\n\x02ts\x18\x02 \x01(\x01\x12\x19\n\x11logical_device_id\x18\x03 \x01(\t\x12\x11\n\tserial_no\x18\x04 \x01(\t\x12\x11\n\tdevice_id\x18\x05 \x01(\t\x12\x34\n\x07\x63ontext\x18\x06 \x03(\x0b\x32#.voltha.MetricMetaData.ContextEntry\x12\x0c\n\x04uuid\x18\x07 \x01(\t\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x10MetricValuePairs\x12\x36\n\x07metrics\x18\x01 \x03(\x0b\x32%.voltha.MetricValuePairs.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xa6\x01\n\x11MetricInformation\x12(\n\x08metadata\x18\x01 \x01(\x0b\x32\x16.voltha.MetricMetaData\x12\x37\n\x07metrics\x18\x02 \x03(\x0b\x32&.voltha.MetricInformation.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xbd\x01\n\x08KpiEvent\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.voltha.KpiEventType.Types\x12\n\n\x02ts\x18\x02 \x01(\x02\x12\x30\n\x08prefixes\x18\x03 \x03(\x0b\x32\x1e.voltha.KpiEvent.PrefixesEntry\x1aI\n\rPrefixesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.voltha.MetricValuePairs:\x02\x38\x01\"p\n\tKpiEvent2\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.voltha.KpiEventType.Types\x12\n\n\x02ts\x18\x02 \x01(\x01\x12-\n\nslice_data\x18\x03 \x03(\x0b\x32\x19.voltha.MetricInformation\"w\n\x0e\x41larmEventType\"e\n\x05Types\x12\x11\n\rCOMMUNICATION\x10\x00\x12\x0f\n\x0b\x45NVIRONMENT\x10\x01\x12\r\n\tEQUIPMENT\x10\x02\x12\x0b\n\x07SERVICE\x10\x03\x12\x0e\n\nPROCESSING\x10\x04\x12\x0c\n\x08SECURITY\x10\x05\"J\n\x12\x41larmEventCategory\"4\n\x05Types\x12\x07\n\x03PON\x10\x00\x12\x07\n\x03OLT\x10\x01\x12\x07\n\x03ONT\x10\x02\x12\x07\n\x03ONU\x10\x03\x12\x07\n\x03NNI\x10\x04\"3\n\x0f\x41larmEventState\" \n\x05Types\x12\n\n\x06RAISED\x10\x00\x12\x0b\n\x07\x43LEARED\x10\x01\"a\n\x12\x41larmEventSeverity\"K\n\x05Types\x12\x11\n\rINDETERMINATE\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x12\t\n\x05MINOR\x10\x02\x12\t\n\x05MAJOR\x10\x03\x12\x0c\n\x08\x43RITICAL\x10\x04\"\xaa\x04\n\nAlarmEvent\x12\n\n\x02id\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.voltha.AlarmEventType.Types\x12\x32\n\x08\x63\x61tegory\x18\x03 \x01(\x0e\x32 .voltha.AlarmEventCategory.Types\x12,\n\x05state\x18\x04 \x01(\x0e\x32\x1d.voltha.AlarmEventState.Types\x12\x32\n\x08severity\x18\x05 \x01(\x0e\x32 .voltha.AlarmEventSeverity.Types\x12-\n\traised_ts\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0breported_ts\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nchanged_ts\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bresource_id\x18\t \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\x12\x30\n\x07\x63ontext\x18\x0b \x03(\x0b\x32\x1f.voltha.AlarmEvent.ContextEntry\x12\x19\n\x11logical_device_id\x18\x0c \x01(\t\x12\x17\n\x0f\x61larm_type_name\x18\r \x01(\t\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb5\x01\n\x0b\x44\x65viceEvent\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65vice_event_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x31\n\x07\x63ontext\x18\x04 \x03(\x0b\x32 .voltha.DeviceEvent.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"v\n\rEventCategory\"e\n\x05Types\x12\x11\n\rCOMMUNICATION\x10\x00\x12\x0f\n\x0b\x45NVIRONMENT\x10\x01\x12\r\n\tEQUIPMENT\x10\x02\x12\x0b\n\x07SERVICE\x10\x03\x12\x0e\n\nPROCESSING\x10\x04\x12\x0c\n\x08SECURITY\x10\x05\"H\n\x10\x45ventSubCategory\"4\n\x05Types\x12\x07\n\x03PON\x10\x00\x12\x07\n\x03OLT\x10\x01\x12\x07\n\x03ONT\x10\x02\x12\x07\n\x03ONU\x10\x03\x12\x07\n\x03NNI\x10\x04\"W\n\tEventType\"J\n\x05Types\x12\x10\n\x0c\x43ONFIG_EVENT\x10\x00\x12\r\n\tKPI_EVENT\x10\x01\x12\x0e\n\nKPI_EVENT2\x10\x02\x12\x10\n\x0c\x44\x45VICE_EVENT\x10\x03\"\x9b\x02\n\x0b\x45ventHeader\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\x08\x63\x61tegory\x18\x02 \x01(\x0e\x32\x1b.voltha.EventCategory.Types\x12\x34\n\x0csub_category\x18\x03 \x01(\x0e\x32\x1e.voltha.EventSubCategory.Types\x12%\n\x04type\x18\x04 \x01(\x0e\x32\x17.voltha.EventType.Types\x12\x14\n\x0ctype_version\x18\x05 \x01(\t\x12-\n\traised_ts\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0breported_ts\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xe4\x01\n\x05\x45vent\x12#\n\x06header\x18\x01 \x01(\x0b\x32\x13.voltha.EventHeader\x12+\n\x0c\x63onfig_event\x18\x02 \x01(\x0b\x32\x13.voltha.ConfigEventH\x00\x12%\n\tkpi_event\x18\x03 \x01(\x0b\x32\x10.voltha.KpiEventH\x00\x12\'\n\nkpi_event2\x18\x04 \x01(\x0b\x32\x11.voltha.KpiEvent2H\x00\x12+\n\x0c\x64\x65vice_event\x18\x05 \x01(\x0b\x32\x13.voltha.DeviceEventH\x00\x42\x0c\n\nevent_typeBE\n\x13org.opencord.volthaZ.github.com/opencord/voltha-protos/v3/go/volthab\x06proto3'
  ,
  dependencies=[voltha__protos_dot_meta__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_CONFIGEVENTTYPE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='voltha.ConfigEventType.Types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='add', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='remove', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='update', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=146,
  serialized_end=186,
)
_sym_db.RegisterEnumDescriptor(_CONFIGEVENTTYPE_TYPES)

_KPIEVENTTYPE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='voltha.KpiEventType.Types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='slice', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ts', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=292,
  serialized_end=318,
)
_sym_db.RegisterEnumDescriptor(_KPIEVENTTYPE_TYPES)

_ALARMEVENTTYPE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='voltha.AlarmEventType.Types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMUNICATION', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENVIRONMENT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUIPMENT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCESSING', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SECURITY', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1164,
  serialized_end=1265,
)
_sym_db.RegisterEnumDescriptor(_ALARMEVENTTYPE_TYPES)

_ALARMEVENTCATEGORY_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='voltha.AlarmEventCategory.Types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PON', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OLT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONU', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NNI', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1289,
  serialized_end=1341,
)
_sym_db.RegisterEnumDescriptor(_ALARMEVENTCATEGORY_TYPES)

_ALARMEVENTSTATE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='voltha.AlarmEventState.Types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RAISED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLEARED', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1362,
  serialized_end=1394,
)
_sym_db.RegisterEnumDescriptor(_ALARMEVENTSTATE_TYPES)

_ALARMEVENTSEVERITY_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='voltha.AlarmEventSeverity.Types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INDETERMINATE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MINOR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAJOR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1418,
  serialized_end=1493,
)
_sym_db.RegisterEnumDescriptor(_ALARMEVENTSEVERITY_TYPES)

_EVENTCATEGORY_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='voltha.EventCategory.Types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMUNICATION', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENVIRONMENT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUIPMENT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCESSING', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SECURITY', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1164,
  serialized_end=1265,
)
_sym_db.RegisterEnumDescriptor(_EVENTCATEGORY_TYPES)

_EVENTSUBCATEGORY_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='voltha.EventSubCategory.Types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PON', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OLT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONU', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NNI', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1289,
  serialized_end=1341,
)
_sym_db.RegisterEnumDescriptor(_EVENTSUBCATEGORY_TYPES)

_EVENTTYPE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='voltha.EventType.Types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONFIG_EVENT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT2', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_EVENT', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2443,
  serialized_end=2517,
)
_sym_db.RegisterEnumDescriptor(_EVENTTYPE_TYPES)


_CONFIGEVENTTYPE = _descriptor.Descriptor(
  name='ConfigEventType',
  full_name='voltha.ConfigEventType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONFIGEVENTTYPE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=186,
)


_CONFIGEVENT = _descriptor.Descriptor(
  name='ConfigEvent',
  full_name='voltha.ConfigEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.ConfigEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='voltha.ConfigEvent.hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='voltha.ConfigEvent.data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=274,
)


_KPIEVENTTYPE = _descriptor.Descriptor(
  name='KpiEventType',
  full_name='voltha.KpiEventType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _KPIEVENTTYPE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=318,
)


_METRICMETADATA_CONTEXTENTRY = _descriptor.Descriptor(
  name='ContextEntry',
  full_name='voltha.MetricMetaData.ContextEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.MetricMetaData.ContextEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.MetricMetaData.ContextEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=545,
)

_METRICMETADATA = _descriptor.Descriptor(
  name='MetricMetaData',
  full_name='voltha.MetricMetaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='voltha.MetricMetaData.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ts', full_name='voltha.MetricMetaData.ts', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logical_device_id', full_name='voltha.MetricMetaData.logical_device_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_no', full_name='voltha.MetricMetaData.serial_no', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.MetricMetaData.device_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='voltha.MetricMetaData.context', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='voltha.MetricMetaData.uuid', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_METRICMETADATA_CONTEXTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=545,
)


_METRICVALUEPAIRS_METRICSENTRY = _descriptor.Descriptor(
  name='MetricsEntry',
  full_name='voltha.MetricValuePairs.MetricsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.MetricValuePairs.MetricsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.MetricValuePairs.MetricsEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=623,
  serialized_end=669,
)

_METRICVALUEPAIRS = _descriptor.Descriptor(
  name='MetricValuePairs',
  full_name='voltha.MetricValuePairs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics', full_name='voltha.MetricValuePairs.metrics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_METRICVALUEPAIRS_METRICSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=669,
)


_METRICINFORMATION_METRICSENTRY = _descriptor.Descriptor(
  name='MetricsEntry',
  full_name='voltha.MetricInformation.MetricsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.MetricInformation.MetricsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.MetricInformation.MetricsEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=623,
  serialized_end=669,
)

_METRICINFORMATION = _descriptor.Descriptor(
  name='MetricInformation',
  full_name='voltha.MetricInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='voltha.MetricInformation.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='voltha.MetricInformation.metrics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_METRICINFORMATION_METRICSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=838,
)


_KPIEVENT_PREFIXESENTRY = _descriptor.Descriptor(
  name='PrefixesEntry',
  full_name='voltha.KpiEvent.PrefixesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.KpiEvent.PrefixesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.KpiEvent.PrefixesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=957,
  serialized_end=1030,
)

_KPIEVENT = _descriptor.Descriptor(
  name='KpiEvent',
  full_name='voltha.KpiEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.KpiEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ts', full_name='voltha.KpiEvent.ts', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefixes', full_name='voltha.KpiEvent.prefixes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_KPIEVENT_PREFIXESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=1030,
)


_KPIEVENT2 = _descriptor.Descriptor(
  name='KpiEvent2',
  full_name='voltha.KpiEvent2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.KpiEvent2.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ts', full_name='voltha.KpiEvent2.ts', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slice_data', full_name='voltha.KpiEvent2.slice_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1032,
  serialized_end=1144,
)


_ALARMEVENTTYPE = _descriptor.Descriptor(
  name='AlarmEventType',
  full_name='voltha.AlarmEventType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALARMEVENTTYPE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1146,
  serialized_end=1265,
)


_ALARMEVENTCATEGORY = _descriptor.Descriptor(
  name='AlarmEventCategory',
  full_name='voltha.AlarmEventCategory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALARMEVENTCATEGORY_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1267,
  serialized_end=1341,
)


_ALARMEVENTSTATE = _descriptor.Descriptor(
  name='AlarmEventState',
  full_name='voltha.AlarmEventState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALARMEVENTSTATE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1394,
)


_ALARMEVENTSEVERITY = _descriptor.Descriptor(
  name='AlarmEventSeverity',
  full_name='voltha.AlarmEventSeverity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALARMEVENTSEVERITY_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1396,
  serialized_end=1493,
)


_ALARMEVENT_CONTEXTENTRY = _descriptor.Descriptor(
  name='ContextEntry',
  full_name='voltha.AlarmEvent.ContextEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.AlarmEvent.ContextEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.AlarmEvent.ContextEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=545,
)

_ALARMEVENT = _descriptor.Descriptor(
  name='AlarmEvent',
  full_name='voltha.AlarmEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.AlarmEvent.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.AlarmEvent.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category', full_name='voltha.AlarmEvent.category', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='voltha.AlarmEvent.state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='voltha.AlarmEvent.severity', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raised_ts', full_name='voltha.AlarmEvent.raised_ts', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reported_ts', full_name='voltha.AlarmEvent.reported_ts', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changed_ts', full_name='voltha.AlarmEvent.changed_ts', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='voltha.AlarmEvent.resource_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='voltha.AlarmEvent.description', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='voltha.AlarmEvent.context', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logical_device_id', full_name='voltha.AlarmEvent.logical_device_id', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alarm_type_name', full_name='voltha.AlarmEvent.alarm_type_name', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ALARMEVENT_CONTEXTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1496,
  serialized_end=2050,
)


_DEVICEEVENT_CONTEXTENTRY = _descriptor.Descriptor(
  name='ContextEntry',
  full_name='voltha.DeviceEvent.ContextEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.DeviceEvent.ContextEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.DeviceEvent.ContextEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=545,
)

_DEVICEEVENT = _descriptor.Descriptor(
  name='DeviceEvent',
  full_name='voltha.DeviceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='voltha.DeviceEvent.resource_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_event_name', full_name='voltha.DeviceEvent.device_event_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='voltha.DeviceEvent.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='voltha.DeviceEvent.context', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEVICEEVENT_CONTEXTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2053,
  serialized_end=2234,
)


_EVENTCATEGORY = _descriptor.Descriptor(
  name='EventCategory',
  full_name='voltha.EventCategory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EVENTCATEGORY_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2236,
  serialized_end=2354,
)


_EVENTSUBCATEGORY = _descriptor.Descriptor(
  name='EventSubCategory',
  full_name='voltha.EventSubCategory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EVENTSUBCATEGORY_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2356,
  serialized_end=2428,
)


_EVENTTYPE = _descriptor.Descriptor(
  name='EventType',
  full_name='voltha.EventType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EVENTTYPE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2430,
  serialized_end=2517,
)


_EVENTHEADER = _descriptor.Descriptor(
  name='EventHeader',
  full_name='voltha.EventHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.EventHeader.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category', full_name='voltha.EventHeader.category', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub_category', full_name='voltha.EventHeader.sub_category', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.EventHeader.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_version', full_name='voltha.EventHeader.type_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raised_ts', full_name='voltha.EventHeader.raised_ts', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reported_ts', full_name='voltha.EventHeader.reported_ts', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2520,
  serialized_end=2803,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='voltha.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='voltha.Event.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_event', full_name='voltha.Event.config_event', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kpi_event', full_name='voltha.Event.kpi_event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kpi_event2', full_name='voltha.Event.kpi_event2', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_event', full_name='voltha.Event.device_event', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event_type', full_name='voltha.Event.event_type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2806,
  serialized_end=3034,
)

_CONFIGEVENTTYPE_TYPES.containing_type = _CONFIGEVENTTYPE
_CONFIGEVENT.fields_by_name['type'].enum_type = _CONFIGEVENTTYPE_TYPES
_KPIEVENTTYPE_TYPES.containing_type = _KPIEVENTTYPE
_METRICMETADATA_CONTEXTENTRY.containing_type = _METRICMETADATA
_METRICMETADATA.fields_by_name['context'].message_type = _METRICMETADATA_CONTEXTENTRY
_METRICVALUEPAIRS_METRICSENTRY.containing_type = _METRICVALUEPAIRS
_METRICVALUEPAIRS.fields_by_name['metrics'].message_type = _METRICVALUEPAIRS_METRICSENTRY
_METRICINFORMATION_METRICSENTRY.containing_type = _METRICINFORMATION
_METRICINFORMATION.fields_by_name['metadata'].message_type = _METRICMETADATA
_METRICINFORMATION.fields_by_name['metrics'].message_type = _METRICINFORMATION_METRICSENTRY
_KPIEVENT_PREFIXESENTRY.fields_by_name['value'].message_type = _METRICVALUEPAIRS
_KPIEVENT_PREFIXESENTRY.containing_type = _KPIEVENT
_KPIEVENT.fields_by_name['type'].enum_type = _KPIEVENTTYPE_TYPES
_KPIEVENT.fields_by_name['prefixes'].message_type = _KPIEVENT_PREFIXESENTRY
_KPIEVENT2.fields_by_name['type'].enum_type = _KPIEVENTTYPE_TYPES
_KPIEVENT2.fields_by_name['slice_data'].message_type = _METRICINFORMATION
_ALARMEVENTTYPE_TYPES.containing_type = _ALARMEVENTTYPE
_ALARMEVENTCATEGORY_TYPES.containing_type = _ALARMEVENTCATEGORY
_ALARMEVENTSTATE_TYPES.containing_type = _ALARMEVENTSTATE
_ALARMEVENTSEVERITY_TYPES.containing_type = _ALARMEVENTSEVERITY
_ALARMEVENT_CONTEXTENTRY.containing_type = _ALARMEVENT
_ALARMEVENT.fields_by_name['type'].enum_type = _ALARMEVENTTYPE_TYPES
_ALARMEVENT.fields_by_name['category'].enum_type = _ALARMEVENTCATEGORY_TYPES
_ALARMEVENT.fields_by_name['state'].enum_type = _ALARMEVENTSTATE_TYPES
_ALARMEVENT.fields_by_name['severity'].enum_type = _ALARMEVENTSEVERITY_TYPES
_ALARMEVENT.fields_by_name['raised_ts'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALARMEVENT.fields_by_name['reported_ts'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALARMEVENT.fields_by_name['changed_ts'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALARMEVENT.fields_by_name['context'].message_type = _ALARMEVENT_CONTEXTENTRY
_DEVICEEVENT_CONTEXTENTRY.containing_type = _DEVICEEVENT
_DEVICEEVENT.fields_by_name['context'].message_type = _DEVICEEVENT_CONTEXTENTRY
_EVENTCATEGORY_TYPES.containing_type = _EVENTCATEGORY
_EVENTSUBCATEGORY_TYPES.containing_type = _EVENTSUBCATEGORY
_EVENTTYPE_TYPES.containing_type = _EVENTTYPE
_EVENTHEADER.fields_by_name['category'].enum_type = _EVENTCATEGORY_TYPES
_EVENTHEADER.fields_by_name['sub_category'].enum_type = _EVENTSUBCATEGORY_TYPES
_EVENTHEADER.fields_by_name['type'].enum_type = _EVENTTYPE_TYPES
_EVENTHEADER.fields_by_name['raised_ts'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTHEADER.fields_by_name['reported_ts'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENT.fields_by_name['header'].message_type = _EVENTHEADER
_EVENT.fields_by_name['config_event'].message_type = _CONFIGEVENT
_EVENT.fields_by_name['kpi_event'].message_type = _KPIEVENT
_EVENT.fields_by_name['kpi_event2'].message_type = _KPIEVENT2
_EVENT.fields_by_name['device_event'].message_type = _DEVICEEVENT
_EVENT.oneofs_by_name['event_type'].fields.append(
  _EVENT.fields_by_name['config_event'])
_EVENT.fields_by_name['config_event'].containing_oneof = _EVENT.oneofs_by_name['event_type']
_EVENT.oneofs_by_name['event_type'].fields.append(
  _EVENT.fields_by_name['kpi_event'])
_EVENT.fields_by_name['kpi_event'].containing_oneof = _EVENT.oneofs_by_name['event_type']
_EVENT.oneofs_by_name['event_type'].fields.append(
  _EVENT.fields_by_name['kpi_event2'])
_EVENT.fields_by_name['kpi_event2'].containing_oneof = _EVENT.oneofs_by_name['event_type']
_EVENT.oneofs_by_name['event_type'].fields.append(
  _EVENT.fields_by_name['device_event'])
_EVENT.fields_by_name['device_event'].containing_oneof = _EVENT.oneofs_by_name['event_type']
DESCRIPTOR.message_types_by_name['ConfigEventType'] = _CONFIGEVENTTYPE
DESCRIPTOR.message_types_by_name['ConfigEvent'] = _CONFIGEVENT
DESCRIPTOR.message_types_by_name['KpiEventType'] = _KPIEVENTTYPE
DESCRIPTOR.message_types_by_name['MetricMetaData'] = _METRICMETADATA
DESCRIPTOR.message_types_by_name['MetricValuePairs'] = _METRICVALUEPAIRS
DESCRIPTOR.message_types_by_name['MetricInformation'] = _METRICINFORMATION
DESCRIPTOR.message_types_by_name['KpiEvent'] = _KPIEVENT
DESCRIPTOR.message_types_by_name['KpiEvent2'] = _KPIEVENT2
DESCRIPTOR.message_types_by_name['AlarmEventType'] = _ALARMEVENTTYPE
DESCRIPTOR.message_types_by_name['AlarmEventCategory'] = _ALARMEVENTCATEGORY
DESCRIPTOR.message_types_by_name['AlarmEventState'] = _ALARMEVENTSTATE
DESCRIPTOR.message_types_by_name['AlarmEventSeverity'] = _ALARMEVENTSEVERITY
DESCRIPTOR.message_types_by_name['AlarmEvent'] = _ALARMEVENT
DESCRIPTOR.message_types_by_name['DeviceEvent'] = _DEVICEEVENT
DESCRIPTOR.message_types_by_name['EventCategory'] = _EVENTCATEGORY
DESCRIPTOR.message_types_by_name['EventSubCategory'] = _EVENTSUBCATEGORY
DESCRIPTOR.message_types_by_name['EventType'] = _EVENTTYPE
DESCRIPTOR.message_types_by_name['EventHeader'] = _EVENTHEADER
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConfigEventType = _reflection.GeneratedProtocolMessageType('ConfigEventType', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGEVENTTYPE,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.ConfigEventType)
  })
_sym_db.RegisterMessage(ConfigEventType)

ConfigEvent = _reflection.GeneratedProtocolMessageType('ConfigEvent', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGEVENT,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.ConfigEvent)
  })
_sym_db.RegisterMessage(ConfigEvent)

KpiEventType = _reflection.GeneratedProtocolMessageType('KpiEventType', (_message.Message,), {
  'DESCRIPTOR' : _KPIEVENTTYPE,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.KpiEventType)
  })
_sym_db.RegisterMessage(KpiEventType)

MetricMetaData = _reflection.GeneratedProtocolMessageType('MetricMetaData', (_message.Message,), {

  'ContextEntry' : _reflection.GeneratedProtocolMessageType('ContextEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICMETADATA_CONTEXTENTRY,
    '__module__' : 'voltha_protos.events_pb2'
    # @@protoc_insertion_point(class_scope:voltha.MetricMetaData.ContextEntry)
    })
  ,
  'DESCRIPTOR' : _METRICMETADATA,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.MetricMetaData)
  })
_sym_db.RegisterMessage(MetricMetaData)
_sym_db.RegisterMessage(MetricMetaData.ContextEntry)

MetricValuePairs = _reflection.GeneratedProtocolMessageType('MetricValuePairs', (_message.Message,), {

  'MetricsEntry' : _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICVALUEPAIRS_METRICSENTRY,
    '__module__' : 'voltha_protos.events_pb2'
    # @@protoc_insertion_point(class_scope:voltha.MetricValuePairs.MetricsEntry)
    })
  ,
  'DESCRIPTOR' : _METRICVALUEPAIRS,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.MetricValuePairs)
  })
_sym_db.RegisterMessage(MetricValuePairs)
_sym_db.RegisterMessage(MetricValuePairs.MetricsEntry)

MetricInformation = _reflection.GeneratedProtocolMessageType('MetricInformation', (_message.Message,), {

  'MetricsEntry' : _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICINFORMATION_METRICSENTRY,
    '__module__' : 'voltha_protos.events_pb2'
    # @@protoc_insertion_point(class_scope:voltha.MetricInformation.MetricsEntry)
    })
  ,
  'DESCRIPTOR' : _METRICINFORMATION,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.MetricInformation)
  })
_sym_db.RegisterMessage(MetricInformation)
_sym_db.RegisterMessage(MetricInformation.MetricsEntry)

KpiEvent = _reflection.GeneratedProtocolMessageType('KpiEvent', (_message.Message,), {

  'PrefixesEntry' : _reflection.GeneratedProtocolMessageType('PrefixesEntry', (_message.Message,), {
    'DESCRIPTOR' : _KPIEVENT_PREFIXESENTRY,
    '__module__' : 'voltha_protos.events_pb2'
    # @@protoc_insertion_point(class_scope:voltha.KpiEvent.PrefixesEntry)
    })
  ,
  'DESCRIPTOR' : _KPIEVENT,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.KpiEvent)
  })
_sym_db.RegisterMessage(KpiEvent)
_sym_db.RegisterMessage(KpiEvent.PrefixesEntry)

KpiEvent2 = _reflection.GeneratedProtocolMessageType('KpiEvent2', (_message.Message,), {
  'DESCRIPTOR' : _KPIEVENT2,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.KpiEvent2)
  })
_sym_db.RegisterMessage(KpiEvent2)

AlarmEventType = _reflection.GeneratedProtocolMessageType('AlarmEventType', (_message.Message,), {
  'DESCRIPTOR' : _ALARMEVENTTYPE,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.AlarmEventType)
  })
_sym_db.RegisterMessage(AlarmEventType)

AlarmEventCategory = _reflection.GeneratedProtocolMessageType('AlarmEventCategory', (_message.Message,), {
  'DESCRIPTOR' : _ALARMEVENTCATEGORY,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.AlarmEventCategory)
  })
_sym_db.RegisterMessage(AlarmEventCategory)

AlarmEventState = _reflection.GeneratedProtocolMessageType('AlarmEventState', (_message.Message,), {
  'DESCRIPTOR' : _ALARMEVENTSTATE,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.AlarmEventState)
  })
_sym_db.RegisterMessage(AlarmEventState)

AlarmEventSeverity = _reflection.GeneratedProtocolMessageType('AlarmEventSeverity', (_message.Message,), {
  'DESCRIPTOR' : _ALARMEVENTSEVERITY,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.AlarmEventSeverity)
  })
_sym_db.RegisterMessage(AlarmEventSeverity)

AlarmEvent = _reflection.GeneratedProtocolMessageType('AlarmEvent', (_message.Message,), {

  'ContextEntry' : _reflection.GeneratedProtocolMessageType('ContextEntry', (_message.Message,), {
    'DESCRIPTOR' : _ALARMEVENT_CONTEXTENTRY,
    '__module__' : 'voltha_protos.events_pb2'
    # @@protoc_insertion_point(class_scope:voltha.AlarmEvent.ContextEntry)
    })
  ,
  'DESCRIPTOR' : _ALARMEVENT,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.AlarmEvent)
  })
_sym_db.RegisterMessage(AlarmEvent)
_sym_db.RegisterMessage(AlarmEvent.ContextEntry)

DeviceEvent = _reflection.GeneratedProtocolMessageType('DeviceEvent', (_message.Message,), {

  'ContextEntry' : _reflection.GeneratedProtocolMessageType('ContextEntry', (_message.Message,), {
    'DESCRIPTOR' : _DEVICEEVENT_CONTEXTENTRY,
    '__module__' : 'voltha_protos.events_pb2'
    # @@protoc_insertion_point(class_scope:voltha.DeviceEvent.ContextEntry)
    })
  ,
  'DESCRIPTOR' : _DEVICEEVENT,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeviceEvent)
  })
_sym_db.RegisterMessage(DeviceEvent)
_sym_db.RegisterMessage(DeviceEvent.ContextEntry)

EventCategory = _reflection.GeneratedProtocolMessageType('EventCategory', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCATEGORY,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.EventCategory)
  })
_sym_db.RegisterMessage(EventCategory)

EventSubCategory = _reflection.GeneratedProtocolMessageType('EventSubCategory', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBCATEGORY,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.EventSubCategory)
  })
_sym_db.RegisterMessage(EventSubCategory)

EventType = _reflection.GeneratedProtocolMessageType('EventType', (_message.Message,), {
  'DESCRIPTOR' : _EVENTTYPE,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.EventType)
  })
_sym_db.RegisterMessage(EventType)

EventHeader = _reflection.GeneratedProtocolMessageType('EventHeader', (_message.Message,), {
  'DESCRIPTOR' : _EVENTHEADER,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.EventHeader)
  })
_sym_db.RegisterMessage(EventHeader)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'voltha_protos.events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Event)
  })
_sym_db.RegisterMessage(Event)


DESCRIPTOR._options = None
_METRICMETADATA_CONTEXTENTRY._options = None
_METRICVALUEPAIRS_METRICSENTRY._options = None
_METRICINFORMATION_METRICSENTRY._options = None
_KPIEVENT_PREFIXESENTRY._options = None
_ALARMEVENT_CONTEXTENTRY._options = None
_DEVICEEVENT_CONTEXTENTRY._options = None
# @@protoc_insertion_point(module_scope)
